@@ -4,8 +4,8 @@ import pandas as pd
 import matplotlib.pyplot as plt
 import numpy as np
 
-def heatmap(x, y, size, figuresize=(10,10), fontsize=20,colour_from_to=(15,235),minimum_size=None, maximum_size=None,
-            size_scale=200,marker_style='o'):
+def heatmap(x, y, value, figuresize=(10,10), fontsize=20,colour_from_to=(15,235),minimum_size=None, maximum_size=None,
+            size_scale=200,marker_style='o',show_grid_lines = True):
     '''
     A function to be used to generate a heatmap using icons with the colour indicating both the direction of the value and the
     size indicating the magnitude.
@@ -33,7 +33,7 @@ def heatmap(x, y, size, figuresize=(10,10), fontsize=20,colour_from_to=(15,235),
     a = heatmap(
         x=corr['x'],
         y=corr['y'],
-        size=corr['value'].abs()
+        value=corr['value']
     )
     
     corr looks like this:
@@ -58,7 +58,9 @@ def heatmap(x, y, size, figuresize=(10,10), fontsize=20,colour_from_to=(15,235),
     17     SibSp     Parch  0.414838
     18     Parch     Parch  1.000000
     '''
-    
+    # convert to size
+    size = np.abs(value)
+
     # get a figure object and set the size
     fig, ax = plt.subplots(figsize=figuresize)
 
@@ -67,17 +69,22 @@ def heatmap(x, y, size, figuresize=(10,10), fontsize=20,colour_from_to=(15,235),
     
     # set the minimum value
     if minimum_size is None:
-        minimum_size = np.min(size)
+        minimum_size = np.min(value)
     
     # set the maximum value
     if maximum_size is None:
-        maximum_size = np.max(size)
+        maximum_size = np.max(value)
+    
+    # protect against the max size being the same as the min size
+    if maximum_size == minimum_size:
+        maximum_size = minimum_size + 0.0000001
         
     color_min, color_max = [minimum_size, maximum_size]
 
     # create a mapping from the string names to integers in sorted order
-    x_labels = [v for v in sorted(x.unique())]
-    y_labels = [v for v in sorted(y.unique())]
+    
+    x_labels = [v for v in sorted(np.unique(x))]
+    y_labels = [v for v in sorted(np.unique(y))]
     x_to_num = {p[1]:p[0] for p in enumerate(x_labels)} 
     y_to_num = {p[1]:p[0] for p in enumerate(y_labels)} 
 
@@ -90,19 +97,30 @@ def heatmap(x, y, size, figuresize=(10,10), fontsize=20,colour_from_to=(15,235),
         ind = int(val_position * (256 - 1))
         return palette[ind]
 
-    ax.scatter(
-        x=x.map(x_to_num),
-        y=y.map(y_to_num),
-        s=size * size_scale,
-        c=size.apply(convert_to_color),
-        marker=marker_style
-    )
+    if 'map' in x.__dir__():
+        ax.scatter(
+            x=x.map(x_to_num),
+            y=y.map(y_to_num),
+            s=size * size_scale,
+            c=value.apply(convert_to_color),
+            marker=marker_style
+        )
+    else:
+        ax.scatter(
+            x=pd.Series(list(map(lambda i: x_to_num[i],x))),
+            y=pd.Series(list(map(lambda i: y_to_num[i],y))),
+            s=pd.Series(list(map(lambda i: i*size_scale,size))),
+            c=list(map(lambda i: convert_to_color(i),value)),
+            marker=marker_style
+        )
 
     # we only want the ticks between the major ticks to show
     ax.grid(False, 'major')
     ax.grid(True, 'minor')
-    ax.set_xticks([t + 0.5 for t in ax.get_xticks()], minor=True)
-    ax.set_yticks([t + 0.5 for t in ax.get_yticks()], minor=True)
+    
+    if show_grid_lines:
+        ax.set_xticks([t + 0.5 for t in ax.get_xticks()], minor=True)
+        ax.set_yticks([t + 0.5 for t in ax.get_yticks()], minor=True)
 
     # Show column labels on the axes
     ax.set_xticks([x_to_num[v] for v in x_labels])
@@ -136,3 +154,39 @@ def heatmap(x, y, size, figuresize=(10,10), fontsize=20,colour_from_to=(15,235),
     ax2.set_yticklabels(np.linspace(min(bar_y), max(bar_y), 3),fontsize=fontsize)
 
     return fig
+
+def correlation_heatmap(df,columns,**kwargs):
+    '''
+    A function to just do a correlation heatmap between the specified columns
+    :param df: The data frame object
+    :param columns: A list of column names to do a correlation between
+    :param kwargs: Key word arguments to be passed to the heatmap function
+    
+    :return fig: A figure object
+    
+    Example Usage:
+    from ds_modules_101 import Plotting as dsp
+    from ds_modules_101.Data import titanic_df
+    import pandas as pd
+    
+    dsp.correlation_heatmap(titanic_df,['Survived','Pclass','SibSp','Parch','Fare'],figuresize=(10, 10))
+    '''
+    
+    data = df[columns].copy()
+    
+    # get a correlation matrix between all columns
+    corr = data.corr()
+    
+    # convert the dataframe by unpivotting so that the first 2 columns are the pair of names and the 3rd column their correlation
+    corr = pd.melt(corr.reset_index(), id_vars='index')
+    
+    # rename the columns
+    corr.columns = ['x', 'y', 'value']
+    
+    # get the heatmap
+    fig = dsp.heatmap(
+        x=corr['x'],
+        y=corr['y'],
+        value=corr['value'],**kwargs
+    )
+    return fig
\ No newline at end of file
